"""
Entiny - A high-performance Python package for Information-Based Optimal Subdata Selection (IBOSS)
"""

__version__ = "0.1.0"

from .core import entiny
from .cli import cli

__all__ = ["entiny", "cli"]
